==> OOo_2.0.0_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/drawing/HomogenMatrix3.hpp <==
#ifndef _COM_SUN_STAR_DRAWING_HOMOGENMATRIX3_HPP_
#define _COM_SUN_STAR_DRAWING_HOMOGENMATRIX3_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_DRAWING_HOMOGENMATRIX3_HDL_
#include "com/sun/star/drawing/HomogenMatrix3.hdl"
#endif

#ifndef _COM_SUN_STAR_DRAWING_HOMOGENMATRIXLINE3_HPP_
#include "com/sun/star/drawing/HomogenMatrixLine3.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace drawing {

inline HomogenMatrix3::HomogenMatrix3() SAL_THROW( () )
    : Line1()
    , Line2()
    , Line3()
{
}

inline HomogenMatrix3::HomogenMatrix3(const ::com::sun::star::drawing::HomogenMatrixLine3& Line1_, const ::com::sun::star::drawing::HomogenMatrixLine3& Line2_, const ::com::sun::star::drawing::HomogenMatrixLine3& Line3_) SAL_THROW( () )
    : Line1(Line1_)
    , Line2(Line2_)
    , Line3(Line3_)
{
}

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::drawing::HomogenMatrix3 const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.drawing.HomogenMatrix3");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
}

#endif // _COM_SUN_STAR_DRAWING_HOMOGENMATRIX3_HPP_

==> OOo_2.0.3_Win32Intel_solver_curvirgo_other.zip: solver/680/wntmsci10.pro/inc/com/sun/star/drawing/HomogenMatrix3.hpp <==
#ifndef _COM_SUN_STAR_DRAWING_HOMOGENMATRIX3_HPP_
#define _COM_SUN_STAR_DRAWING_HOMOGENMATRIX3_HPP_

#ifndef _SAL_CONFIG_H_
#include "sal/config.h"
#endif

#ifndef _COM_SUN_STAR_DRAWING_HOMOGENMATRIX3_HDL_
#include "com/sun/star/drawing/HomogenMatrix3.hdl"
#endif

#ifndef _COM_SUN_STAR_DRAWING_HOMOGENMATRIXLINE3_HPP_
#include "com/sun/star/drawing/HomogenMatrixLine3.hpp"
#endif
#ifndef _COM_SUN_STAR_UNO_TYPE_HXX_
#include "com/sun/star/uno/Type.hxx"
#endif
#ifndef INCLUDED_CPPU_UNOTYPE_HXX
#include "cppu/unotype.hxx"
#endif
#ifndef _SAL_TYPES_H_
#include "sal/types.h"
#endif
#ifndef _TYPELIB_TYPECLASS_H_
#include "typelib/typeclass.h"
#endif
#ifndef _TYPELIB_TYPEDESCRIPTION_H_
#include "typelib/typedescription.h"
#endif

namespace com { namespace sun { namespace star { namespace drawing {

inline HomogenMatrix3::HomogenMatrix3() SAL_THROW( () )
    : Line1()
    , Line2()
    , Line3()
{
}

inline HomogenMatrix3::HomogenMatrix3(const ::com::sun::star::drawing::HomogenMatrixLine3& Line1_, const ::com::sun::star::drawing::HomogenMatrixLine3& Line2_, const ::com::sun::star::drawing::HomogenMatrixLine3& Line3_) SAL_THROW( () )
    : Line1(Line1_)
    , Line2(Line2_)
    , Line3(Line3_)
{
}

} } } }

namespace com { namespace sun { namespace star { namespace drawing {

inline ::com::sun::star::uno::Type const & cppu_detail_getUnoType(::com::sun::star::drawing::HomogenMatrix3 const *) {
    //TODO: On certain platforms with weak memory models, the following code can result in some threads observing that the_type points to garbage
    static ::typelib_TypeDescriptionReference * the_type = 0;
    if (the_type == 0) {
        ::typelib_static_type_init(&the_type, typelib_TypeClass_STRUCT, "com.sun.star.drawing.HomogenMatrix3");
    }
    return *reinterpret_cast< ::com::sun::star::uno::Type * >(&the_type);
};

} } } }

inline ::com::sun::star::uno::Type const & SAL_CALL getCppuType(::com::sun::star::drawing::HomogenMatrix3 const *) SAL_THROW(()) {
    return ::cppu::UnoType< ::com::sun::star::drawing::HomogenMatrix3 >::get();
}

#endif // _COM_SUN_STAR_DRAWING_HOMOGENMATRIX3_HPP_
